#
# spec file for package python-QtPy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%bcond_without test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-QtPy
Version:        1.4.1
Release:        lp151.2.2
License:        MIT
Summary:        Abstraction layer on top of Qt bindings
Url:            https://github.com/spyder-ide/qtpy
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/Q/QtPy/QtPy-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module sip}
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-qt5
Requires:       python-sip
BuildArch:      noarch

%python_subpackages

%description
QtPy (pronounced 'cutie pie') is a small abstraction layer that lets you
write applications using a single api call to either PyQt or PySide.

It provides support for PyQt5, PyQt4 and PySide using the PyQt5 layout (where
the QtGui module has been split into QtGui and QtWidgets).

Basically, you write your code as if you were using PyQt5 but import qt from
`qtpy` instead of `PyQt5`.

%prep
%setup -q -n QtPy-%{version}
sed -i 's/\r$//' LICENSE.txt

%build
%python_build

%install
%python_install
%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/qtpy/tests/runtests.py
sed -i "s|^#!/usr/bin/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/qtpy/tests/runtests.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/qtpy/tests/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/qtpy/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE.txt
%{python_sitelib}/*

%changelog
* Sat Apr 28 2018 toddrme2178@gmail.com
- Update to Version 1.4.1
  + New features
  * Show a warning when QT_API is changed automatically by qtpy.
  + Issues Closed
  * Raise a warning if QT_API value is changed automatically
  * On OSX qtpy applications are forcing discrete graphics
  + Pull Requests Merged
  * Add better compatibility with PySide2
  * Add a warning if API is changed automatically
  * Avoid using PyQt5.Qt, which imports unneeded stuff and forces
    discrete GPU on OSX
- Update to Version 1.4 (2018-03-11)
  + New features
  * Add support for QtHelp
  * Add support for QtSql
  * Use already imported bindings
  + Issues Closed
  * If one binding has already been imported,
    then qtpy should just use it
  * Add Wrapper for QtSql
  * Methods missing from QStandardPaths when QT_API=pyqt4
  * Add Wrapper for QtHelp
  + Pull Requests Merged
  * Pin PyQt5 to 5.9.2 in CircleCI because 5.10 is generating segfaults
  * If a Qt binding is already imported, then use it.
  * Add QtSql wrapper (incl. test)
  * Changes to QDesktop split
  * Add QtHelp Wrapper
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to Version 1.3.1
  + Bugs fixed
  * Spurious cache files in PyPI tarball
  * Importing qtpy should not raise exceptions
  * No cache files included in the release tarball
  * Remove Quantified Code badge because the service doesn't exist anymore
  * Warn if QHeaderView deprecated methods are used
- Update to Version 1.3
  + New features
  * Add support for PySide2
  * Add support for QtMultimedia
  * Add support for PyQt 4.6
  + Bugs fixed
  * Typo in readme title
  * Update Readme for 1.3 release
  * Add tests for untested modules
  * Missing: QtOpenGL Module
  * QDesktopServices split into QDesktopServices and QStandardPaths
  * qInstallMessageHandler <-> qInstallMsgHandler
  * Feature Request: PySide2 support
  * Fix typo in Readme.
  * Add compatibility for the rename of qInstallMsgHandler to qInstallMessageHandler
  * Update Readme to reflect that we actually use the PySide2 layout
  * Update Readme to mention that we now support PySide2.
  * Add tests for Qtdesigner, QtNetwork, QtPrintSupport, QtSvg and QtTest.
  * Follow QStandardPaths location in Qt5 for PyQt4/PySide
  * Add a coveragerc file
  * Add support for PyQt 4.6
  * Add a new QtOpenGL module
  * Add PySide2 support
* Fri Apr 28 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Feb 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.2.1
  - Bugs fixed:
    Pull requests
    + PR 98 - PR: Don't use Travis to test macOS because it slows
    down the entire spyder-ide organization
    + PR 97 - PR: Update Appveyor badge in Readme because of moving
    to an org account
    + PR 94 - PR: Include test suite in sdist
- Version 1.2
  - New features:
    + Add support for QtMultimedia
    + Use relative imports so its vendored more easily
  - Bugs fixed:
    Issues
    + Issue 83 - Include core doc files in PyPi releases
    + Issue 78 - Request for a new bugfix release
    + Issue 75 - Missing copyright headers
    + Issue 67 - uic.loadUiType is missing
    + Issue 64 - QHeaderView.setSectionResizeMode
    + Issue 49 - QtMultimedia support
    Pull requests
    + PR 93 - Restore uic full namespace for PyQt5 and PyQt4
    + PR 92 - Add missing copyright header in _patch/qheaderview.py
    + PR 91 - Use star imports in QtSvg again instead of direct
    ones (reverts PR #55)
    + PR 88 - PR: Add manifest
    + PR 74 - Move QStringListModel to QtCore
    + PR 71 - PR: Use relative imports so its vendored more easily
    + PR 65 - Introduce renamed methods of QHeaderView in PyQt4 and
    PySide
    + PR 59 - Don't install qtpy as a conda package in CircleCI
    + PR 58 - Remove reference to how qtpy is pronounced in README
    + PR 55 - PR: Add explicit imports to QtSvg module
    + PR 50 - Add support for QtMultimedia
- Removed source file LICENSE.txt, fixed upstream.
* Thu Oct 13 2016 toddrme2178@gmail.com
- Initial version
